Enum sc_finality_grandpa::FinalityProofError [−][src]
pub enum FinalityProofError {
BlockNotYetFinalized,
BlockNotInAuthoritySetChanges,
Client(Error),
}Expand description
Errors occurring when trying to prove finality
Variants
The requested block has not yet been finalized.
The requested block is not covered by authority set changes. Likely this means the block is in the latest authority set, and the subscription API is more appropriate.
Client(Error)Errors originating from the client.
Tuple Fields of Client
0: ErrorTrait Implementations
Performs the conversion.